@@ -2,15 +2,15 @@ package Solution;
 {
     use strict;
     use warnings;
-    our $VERSION = '0.9.1';
-    use Solution::Document;
-    use Solution::Context;
-    use Solution::Tag;
-    use Solution::Block;
-    use Solution::Condition;
-    use Solution::Template;
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -4; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
 
     #
+    use Solution::Document;
+    use Solution::Block;
+    use Solution::Condition;
+    use Solution::Context;
+    use Solution::Tag;
+    use Solution::Template;
     {    # Load all the tags from the standard library
         require File::Find;
         require File::Spec;
@@ -237,50 +237,16 @@ L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.or
 See the
 L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
+=for git $Id: Solution.pm 76e9e91 2010-09-21 02:58:26Z sanko@cpan.org $
+
 =cut
 {
-    { package Solution::Drop;           our $VERSION = '0.9.1'; }
-    { package Solution::Extensions;     our $VERSION = '0.9.1'; }
-    { package Solution::HTMLTags;       our $VERSION = '0.9.1'; }
-    { package Solution::Module_Ex;      our $VERSION = '0.9.1'; }
-    { package Solution::Strainer;       our $VERSION = '0.9.1'; }
-    { package Solution::Tag::IfChanged; our $VERSION = '0.9.1'; }
-
-    #
-    { package Liquid;                   our $VERSION = '0.9.1' }
-    { package Liquid::Variable;         our $VERSION = '0.9.1' }
-    { package Liquid::Utility;          our $VERSION = '0.9.1' }
-    { package Liquid::Template;         our $VERSION = '0.9.1' }
-    { package Liquid::Tag;              our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Unless;      our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Raw;         our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Include;     our $VERSION = '0.9.1' }
-    { package Liquid::Tag::IfChanged;   our $VERSION = '0.9.1' }
-    { package Liquid::Tag::If;          our $VERSION = '0.9.1' }
-    { package Liquid::Tag::For;         our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Cycle;       our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Comment;     our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Case;        our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Capture;     our $VERSION = '0.9.1' }
-    { package Liquid::Tag::Assign;      our $VERSION = '0.9.1' }
-    { package Liquid::SyntaxError;      our $VERSION = '0.9.1' }
-    { package Liquid::Strainer;         our $VERSION = '0.9.1' }
-    { package Liquid::StandardError;    our $VERSION = '0.9.1' }
-    { package Liquid::StackLevelError;  our $VERSION = '0.9.1' }
-    { package Liquid::Module_Ex;        our $VERSION = '0.9.1' }
-    { package Liquid::HTMLTags;         our $VERSION = '0.9.1' }
-    { package Liquid::FilterNotFound;   our $VERSION = '0.9.1' }
-    { package Liquid::Filter::Standard; our $VERSION = '0.9.1' }
-    { package Liquid::FileSystemError;  our $VERSION = '0.9.1' }
-    { package Liquid::Extensions;       our $VERSION = '0.9.1' }
-    { package Liquid::Error;            our $VERSION = '0.9.1' }
-    { package Liquid::Drop;             our $VERSION = '0.9.1' }
-    { package Liquid::Document;         our $VERSION = '0.9.1' }
-    { package Liquid::ContextError;     our $VERSION = '0.9.1' }
-    { package Liquid::Context;          our $VERSION = '0.9.1' }
-    { package Liquid::Condition;        our $VERSION = '0.9.1' }
-    { package Liquid::Block;            our $VERSION = '0.9.1' }
-    { package Liquid::ArgumentError;    our $VERSION = '0.9.1' }
+    { package Solution::Drop; }
+    { package Solution::Extensions; }
+    { package Solution::HTMLTags; }
+    { package Solution::Module_Ex; }
+    { package Solution::Strainer; }
+    { package Solution::Tag::IfChanged; }
 }
 1;
 __END__
