@@ -2,7 +2,7 @@ package Solution::Block;
 {
     use strict;
     use warnings;
-    our $VERSION = '0.9.1';
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -1; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     use lib '../../lib';
     use Solution::Error;
     our @ISA = qw[Solution::Document];
@@ -29,32 +29,28 @@ package Solution::Block;
                           parent     => $args->{'parent'},
         }, $class;
         $self->{'conditions'} = (
-            $args->{'tag_name'} eq 'else' ?
-                [1]
+            $args->{'tag_name'} eq 'else'
+            ? [1]
             : sub {    # Oh, what a mess...
-                my @conditions
-                    = split m[\s+\b(and|or)\b\s+],
-                    $args->{parent}->{tag_name} eq 'for' ?
-                    1
-                    : (defined $args->{'attrs'} ? $args->{'attrs'} : '');
+                my @conditions = split m[\s+\b(and|or)\b\s+],
+                    (defined $args->{'attrs'} ? $args->{'attrs'} : '');
                 my @equality;
                 while (my $x = shift @conditions) {
                     push @equality, (
                         $x =~ m[\b(?:and|or)\b]    # XXX - ARG
-                        ?
-                            bless({template  => $args->{'template'},
-                                   parent    => $self,
-                                   condition => $x,
-                                   lvalue    => pop @equality,
-                                   rvalue =>
-                                       Solution::Condition->new(
+                        ? bless({template  => $args->{'template'},
+                                 parent    => $self,
+                                 condition => $x,
+                                 lvalue    => pop @equality,
+                                 rvalue =>
+                                     Solution::Condition->new(
                                           {template => $args->{'template'},
                                            parent   => $self,
                                            attrs    => shift @conditions
                                           }
-                                       )
-                                  },
-                                  'Solution::Condition'
+                                     )
+                                },
+                                'Solution::Condition'
                             )
                         : Solution::Condition->new(
                                           {attrs    => $x,
@@ -116,7 +112,7 @@ The original Liquid template system was developed by jadedPixel
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
@@ -128,4 +124,6 @@ covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
+=for git $Id: Block.pm 76e9e91 2010-09-21 02:58:26Z sanko@cpan.org $
+
 =cut
