@@ -2,11 +2,11 @@ package Solution::Tag::For;
 {
     use strict;
     use warnings;
-    our $VERSION = '0.9.1';
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -4; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     use lib '../../../lib';
     use Solution::Error;
     use Solution::Utility;
-    our @ISA = qw[Solution::Tag::If];
+    our @ISA = qw[Solution::Tag];
     my $Help_String = 'TODO';
     Solution->register_tag('for', __PACKAGE__) if $Solution::VERSION;
 
@@ -34,15 +34,14 @@ package Solution::Tag::For;
         my ($var, $range, $attr) = ($1, $2, $3 || '');
         my $reversed = $attr =~ s[^reversed\b][] ? 1 : 0;
         my %attr = map {
-            my ($k, $v)
-                = split($Solution::Utility::FilterArgumentSeparator, $_, 2);
+            my ($k, $v) = split( $Solution::Utility::FilterArgumentSeparator,
+                $_, 2);
             { $k => $v };
-        } grep { defined && length } split qr[\s+], $attr || '';
+        } grep {defined && length} split qr[\s+], $attr || '';
         my $self = bless {attributes      => \%attr,
                           collection_name => $range,
                           name            => $var . '-' . $range,
-                          blocks          => [],
-                          conditional_tag => 'else',
+                          nodelist        => [],
                           reversed        => $reversed,
                           tag_name        => $args->{'tag_name'},
                           variable_name   => $var,
@@ -59,51 +58,43 @@ package Solution::Tag::For;
         my $range    = $self->{'collection_name'};
         my $attr     = $self->{'attributes'};
         my $reversed = $self->{'reversed'};
-        my $sorted
-            = exists $attr->{'sorted'} ?
-            $self->resolve($attr->{'sorted'}) || $attr->{'sorted'} || 'key'
+        my $sorted   = exists $attr->{'sorted'}
+            ? $self->resolve($attr->{'sorted'}) || $attr->{'sorted'} || 'key'
             : ();
-        $sorted = 'key'
-            if (defined $sorted
-                && (($sorted ne 'key') && ($sorted ne 'value')));
+        $sorted = 'key' if (defined $sorted && ( ($sorted ne 'key') && ($sorted ne 'value')));
         my $offset
-            = defined $attr->{'offset'} ?
-            $self->resolve($attr->{'offset'})
+            = defined $attr->{'offset'}
+            ? $self->resolve($attr->{'offset'})
             : ();
         my $limit
-            = defined $attr->{'limit'} ?
-            $self->resolve($attr->{'limit'})
+            = defined $attr->{'limit'}
+            ? $self->resolve($attr->{'limit'})
             : ();
-        my $list = $self->resolve($range);
+        my $list = $self->resolve($range) || [];
         my $type = 'ARRAY';
 
+
         #
-        my $_undef_list = 0;
         if (ref $list eq 'HASH') {
             $list = [map { {key => $_, value => $list->{$_}} } keys %$list];
             @$list = sort {
-                $a->{$sorted} =~ m[^\d+$] && $b->{$sorted} =~ m[^\d+$]
-                    ?
-                    ($a->{$sorted} <=> $b->{$sorted})
-                    : ($a->{$sorted} cmp $b->{$sorted})
+                    $a->{$sorted} =~ m[^\d+$] && $b->{$sorted} =~ m[^\d+$] ?
+                    ( $a->{$sorted} <=> $b->{$sorted} ) :
+                    ( $a->{$sorted} cmp $b->{$sorted} )
             } @$list if defined $sorted;
             $type = 'HASH';
         }
         elsif (defined $sorted) {
             @$list = sort {
-                $a =~ m[^\d+$] && $b =~ m[^\d+$] ?
-                    ($a <=> $b)
-                    : ($a cmp $b)
+                    $a =~ m[^\d+$] && $b =~ m[^\d+$] ?
+                    ($a <=> $b) :
+                    ( $a cmp $b )
             } @$list;
         }
-        if (!defined $list || !$list || !@$list) {
-            $_undef_list = 1;
-            $list        = [1];
-        }
-        else {    # Break it down to only the items we plan on using
+        {    # Break it down to only the items we plan on using
             my $min = (defined $offset ? $offset : 0);
-            my $max = (defined $limit ?
-                           $limit + (defined $offset ? $offset : 0) - 1
+            my $max = (defined $limit
+                       ? $limit + (defined $offset ? $offset : 0) - 1
                        : $#$list
             );
             $max    = $#$list if $max > $#$list;
@@ -115,9 +106,8 @@ package Solution::Tag::For;
         return $self->template->context->stack(
             sub {
                 my $return = '';
+                my $nodes  = $self->{'nodelist'};
                 my $steps  = $#$list;
-                $_undef_list = 1 if $steps == -1;
-                my $nodes = $self->{'blocks'}[$_undef_list]{'nodelist'};
                 for my $index (0 .. $steps) {
                     $self->template->context->scope
                         ->{$self->{'variable_name'}} = $list->[$index];
@@ -280,21 +270,6 @@ the C<item.key> and C<item.value> variables. ...here's an example:
 The C<forloop.type> variable will contain C<HASH> if the looped variable is a
 hashref. Also note that the keys/value pairs are left unsorted.
 
-=head2 C<else> tag
-
-The else tag allows us to do this:
-
-    {% for item in collection %}
-        Item {{ forloop.index }}: {{ item.name }}
-    {% else %}
-        There is nothing in the collection.
-    {% endfor %}
-
-The C<else> branch is executed whenever the for branch will never be executed
-(e.g. collection is blank or not an iterable or out of iteration scope).
-
-=for basis https://github.com/Shopify/liquid/pull/56
-
 =head1 TODO
 
 Since this is a customer facing template engine, Liquid should provide some
@@ -325,7 +300,7 @@ CPAN ID: SANKO
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009,2010 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of
@@ -340,4 +315,6 @@ L<Creative Commons Attribution-Share Alike 3.0 License|http://creativecommons.or
 See the
 L<clarification of the CCA-SA3.0|http://creativecommons.org/licenses/by-sa/3.0/us/>.
 
+=for git $Id: For.pm 76e9e91 2010-09-21 02:58:26Z sanko@cpan.org $
+
 =cut
