@@ -2,19 +2,19 @@ package Solution::Utility;
 {
     use strict;
     use warnings;
-    our $VERSION = '0.9.1';
+    our $MAJOR = 0.0; our $MINOR = 0; our $DEV = -3; our $VERSION = sprintf('%1d.%02d' . ($DEV ? (($DEV < 0 ? '' : '_') . '%02d') : ('')), $MAJOR, $MINOR, abs $DEV);
     our $FilterSeparator = qr[\s*\|\s*];
     my $ArgumentSeparator = qr[,];
-    our $FilterArgumentSeparator    = qr[\s*:\s*];
+    our $FilterArgumentSeparator    = qr[:];
     our $VariableAttributeSeparator = qr[\.];
     our $TagStart                   = qr[{%\s*];
     our $TagEnd                     = qr[\s*%}];
     our $VariableSignature          = qr[\(?[\w\-\.\[\]]\)?];
     my $VariableSegment = qr[[\w\-]\??]x;
-    our $VariableStart = qr[\{\{\s*];
+    our $VariableStart = qr[{{\s*];
     our $VariableEnd   = qr[\s*}}];
     my $VariableIncompleteEnd = qr[}}?];
-    my $QuotedString          = qr/"(?:[^"\\]|\\.)*"|'(?:[^'\\]|\\.)*'/;
+    my $QuotedString          = qr/"[^"]+"|'[^']+'/;
     my $QuotedFragment = qr/${QuotedString}|(?:[^\s,\|'"]|${QuotedString})+/;
     my $StrictQuotedFragment = qr/"[^"]+"|'[^']+'|[^\s,\|,\:,\,]+/;
     my $FirstFilterArgument
@@ -35,9 +35,8 @@ package Solution::Utility;
                                 (?:\s*\|\s*(.+)\s*)?                 #   filters
                             ${VariableEnd}                          # }}
                             $]x;
-
     our $VariableFilterArgumentParser
-        = qr[\s*,\s*(?=(?:[^\']*\'[^\']*\')*(?![^\']*\'))];
+        = qr[\s*,\s*(?=(?:[^\"]*\"[^\"]*\")*(?![^\"]*\"))];
 
     sub tokenize {
         map { $_ ? $_ : () } split $TemplateParser, shift || '';
@@ -70,7 +69,7 @@ The original Liquid template system was developed by jadedPixel
 
 =head1 License and Legal
 
-Copyright (C) 2009-2012 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
+Copyright (C) 2009 by Sanko Robinson E<lt>sanko@cpan.orgE<gt>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of The Artistic License 2.0.  See the F<LICENSE> file included with
@@ -82,4 +81,6 @@ covered by the Creative Commons Attribution-Share Alike 3.0 License.  See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
+=for git $Id: Utility.pm 76e9e91 2010-09-21 02:58:26Z sanko@cpan.org $
+
 =cut
